import { Column, CreateDateColumn, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn } from "typeorm";
import { equipment } from "../equipment/equipment";
import { vehicle } from "../vehicle/vehicle";
import { PlanTimeDefinition } from "../../../viewmodel/admin/unit/inspection/inspectionPlan.models";
import { inspectionVersionedPlan } from "./inspectionVersionedPlan";

@Entity()
export class inspectionPlan {
  @PrimaryGeneratedColumn("uuid")
  id: string;

  @Column({ type: "varchar", length: 255 })
  title: string;

  @Column({ type: "varchar", length: 255 })
  inspectionInterval: PlanTimeDefinition;

  @Column({ type: "varchar", length: 255 })
  remindTime: PlanTimeDefinition;

  @CreateDateColumn()
  createdAt: Date;

  @Column()
  equipmentId?: string;

  @Column()
  vehicleId?: string;

  @ManyToOne(() => equipment, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  equipment?: equipment;

  @ManyToOne(() => vehicle, {
    nullable: true,
    onDelete: "CASCADE",
    onUpdate: "RESTRICT",
  })
  vehicle?: vehicle;

  @OneToMany(() => inspectionVersionedPlan, (ivp) => ivp.inspectionPlan, {
    cascade: ["insert"],
  })
  versionedPlans: inspectionVersionedPlan[];

  latestVersionedPlan?: inspectionVersionedPlan;
}
