import { dataSource } from "../../../data-source";
import { inspectionPlan } from "../../../entity/unit/inspection/inspectionPlan";
import { DB_TYPE } from "../../../env.defaults";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class InspectionPlanService {
  /**
   * @description get all inspectionPlans for related
   * @returns {Promise<Array<inspectionPlan>>}
   */
  static async getAllForRelated(
    where: { equipmentId: string } | { vehicleId: string }
  ): Promise<Array<inspectionPlan>> {
    return await dataSource
      .getRepository(inspectionPlan)
      .createQueryBuilder("inspectionPlan")
      .leftJoinAndMapOne(
        "inspectionPlan.latestVersionedPlan",
        "inspectionPlan.versionedPlans",
        "latestVersionedPlan",
        DB_TYPE == "postgres"
          ? 'latestVersionedPlan.inspectionPlanId = inspectionPlan.id AND latestVersionedPlan.version = (SELECT MAX("ivp"."start") FROM "inspection_versioned_plan" "ivp" WHERE "ivp"."inspectionPlanId" = "inspectionPlan"."id")'
          : "latestVersionedPlan.inspectionPlanId = inspectionPlan.id AND latestVersionedPlan.version = (SELECT MAX(ivp.start) FROM inspection_versioned_plan ivp WHERE ivp.inspectionPlanId = inspectionPlan.id)"
      )
      .leftJoinAndSelect("latestVersionedPlan.inspectionPoints", "inspectionPoints")
      .leftJoinAndSelect("inspectionPlan.equipment", "equipment")
      .leftJoinAndSelect("inspectionPlan.vehicle", "vehicle")
      .where(where)
      .orderBy("title", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionPlan", err);
      });
  }

  /**
   * @description get inspectionPlan by id
   * @returns {Promise<inspectionPlan>}
   */
  static async getById(id: string): Promise<inspectionPlan> {
    return await dataSource
      .getRepository(inspectionPlan)
      .createQueryBuilder("inspectionPlan")
      .leftJoinAndMapOne(
        "inspectionPlan.latestVersionedPlan",
        "inspectionPlan.versionedPlans",
        "latestVersionedPlan",
        DB_TYPE == "postgres"
          ? 'latestVersionedPlan.inspectionPlanId = inspectionPlan.id AND latestVersionedPlan.version = (SELECT MAX("ivp"."start") FROM "inspection_versioned_plan" "ivp" WHERE "ivp"."inspectionPlanId" = "inspectionPlan"."id")'
          : "latestVersionedPlan.inspectionPlanId = inspectionPlan.id AND latestVersionedPlan.version = (SELECT MAX(ivp.start) FROM inspection_versioned_plan ivp WHERE ivp.inspectionPlanId = inspectionPlan.id)"
      )
      .leftJoinAndSelect("latestVersionedPlan.inspectionPoints", "inspectionPoints")
      .leftJoinAndSelect("inspectionPlan.equipment", "equipment")
      .leftJoinAndSelect("inspectionPlan.vehicle", "vehicle")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionPlan", err);
      });
  }
}
