import { dataSource } from "../../../data-source";
import { inspectionVersionedPlan } from "../../../entity/unit/inspection/inspectionVersionedPlan";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class InspectionVersionedPlanService {
  /**
   * @description get all inspectionVersionedPlans
   * @returns {Promise<Array<inspectionVersionedPlan>>}
   */
  static async getAllForInspectionPlan(inspectionPlanId: string): Promise<Array<inspectionVersionedPlan>> {
    return await dataSource
      .getRepository(inspectionVersionedPlan)
      .createQueryBuilder("inspectionVersionedPlan")
      .leftJoinAndSelect("inspectionVersionedPlan.inspectionPoints", "inspectionPoints")
      .where({ inspectionPlanId })
      .orderBy("version", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionVersionedPlan", err);
      });
  }

  /**
   * @description get inspectionVersionedPlan by id
   * @returns {Promise<inspectionVersionedPlan>}
   */
  static async getById(id: string): Promise<inspectionVersionedPlan> {
    return await dataSource
      .getRepository(inspectionVersionedPlan)
      .createQueryBuilder("inspectionVersionedPlan")
      .leftJoinAndSelect("inspectionVersionedPlan.inspectionPoints", "inspectionPoints")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "inspectionVersionedPlan", err);
      });
  }
}
