import { dataSource } from "../../../data-source";
import { vehicle } from "../../../entity/unit/vehicle/vehicle";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class VehicleService {
  /**
   * @description get all vehicles
   * @returns {Promise<Array<vehicle>>}
   */
  static async getAll(): Promise<Array<vehicle>> {
    return await dataSource
      .getRepository(vehicle)
      .createQueryBuilder("vehicle")
      .leftJoinAndSelect("vehicle.vehicleType", "vehicletype")
      .orderBy("name", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "vehicle", err);
      });
  }

  /**
   * @description get vehicle by id
   * @returns {Promise<vehicle>}
   */
  static async getById(id: string): Promise<vehicle> {
    return await dataSource
      .getRepository(vehicle)
      .createQueryBuilder("vehicle")
      .leftJoinAndSelect("vehicle.vehicleType", "vehicletype")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "vehicle", err);
      });
  }
}
