import { dataSource } from "../../../data-source";
import { vehicleType } from "../../../entity/unit/vehicle/vehicleType";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class VehicleTypeService {
  /**
   * @description get all vehicleTypes
   * @returns {Promise<Array<vehicleType>>}
   */
  static async getAll(): Promise<Array<vehicleType>> {
    return await dataSource
      .getRepository(vehicleType)
      .createQueryBuilder("vehicleType")
      .orderBy("type", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "vehicleType", err);
      });
  }

  /**
   * @description get vehicleType by id
   * @returns {Promise<vehicleType>}
   */
  static async getById(id: string): Promise<vehicleType> {
    return await dataSource
      .getRepository(vehicleType)
      .createQueryBuilder("vehicleType")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "vehicleType", err);
      });
  }
}
