import { dataSource } from "../../../data-source";
import { wearableType } from "../../../entity/unit/wearable/wearableType";
import DatabaseActionException from "../../../exceptions/databaseActionException";

export default abstract class WearableTypeService {
  /**
   * @description get all wearableTypes
   * @returns {Promise<Array<wearableType>>}
   */
  static async getAll(): Promise<Array<wearableType>> {
    return await dataSource
      .getRepository(wearableType)
      .createQueryBuilder("wearableType")
      .orderBy("type", "ASC")
      .getMany()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "wearableType", err);
      });
  }

  /**
   * @description get wearableType by id
   * @returns {Promise<wearableType>}
   */
  static async getById(id: string): Promise<wearableType> {
    return await dataSource
      .getRepository(wearableType)
      .createQueryBuilder("wearableType")
      .where({ id })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new DatabaseActionException("SELECT", "wearableType", err);
      });
  }
}
